@@ -60,12 +60,8 @@ class Enforcer(policy.Enforcer):
            :raises: `glance.common.exception.Forbidden`
            :returns: A non-False value if access is allowed.
         """
-        credentials = {
-            'roles': context.roles,
-            'user': context.user,
-            'tenant': context.tenant,
-        }
-        return super(Enforcer, self).enforce(action, target, credentials,
+        return super(Enforcer, self).enforce(action, target,
+                                             context.to_policy_values(),
                                              do_raise=True,
                                              exc=exception.Forbidden,
                                              action=action)
@@ -78,12 +74,9 @@ class Enforcer(policy.Enforcer):
            :param target: Dictionary representing the object of the action.
            :returns: A non-False value if access is allowed.
         """
-        credentials = {
-            'roles': context.roles,
-            'user': context.user,
-            'tenant': context.tenant,
-        }
-        return super(Enforcer, self).enforce(action, target, credentials)
+        return super(Enforcer, self).enforce(action,
+                                             target,
+                                             context.to_policy_values())
 
     def check_is_admin(self, context):
         """Check if the given context is associated with an admin role,
@@ -129,6 +122,13 @@ class ImageRepoProxy(glance.domain.proxy.Repo):
         return super(ImageRepoProxy, self).add(image)
 
 
+def _enforce_image_visibility(policy, context, visibility, target):
+    if visibility == 'public':
+        policy.enforce(context, 'publicize_image', target)
+    elif visibility == 'community':
+        policy.enforce(context, 'communitize_image', target)
+
+
 class ImageProxy(glance.domain.proxy.Image):
 
     def __init__(self, image, context, policy):
@@ -144,8 +144,8 @@ class ImageProxy(glance.domain.proxy.Image):
 
     @visibility.setter
     def visibility(self, value):
-        if value == 'public':
-            self.policy.enforce(self.context, 'publicize_image', self.target)
+        _enforce_image_visibility(self.policy, self.context, value,
+                                  self.target)
         self.image.visibility = value
 
     @property
@@ -213,8 +213,8 @@ class ImageFactoryProxy(glance.domain.proxy.ImageFactory):
                                                 proxy_kwargs=proxy_kwargs)
 
     def new_image(self, **kwargs):
-        if kwargs.get('visibility') == 'public':
-            self.policy.enforce(self.context, 'publicize_image', {})
+        _enforce_image_visibility(self.policy, self.context,
+                                  kwargs.get('visibility'), {})
         return super(ImageFactoryProxy, self).new_image(**kwargs)
 
 
