@@ -12,11 +12,13 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+from cursive import exception as cursive_exception
 import glance_store
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import encodeutils
 from oslo_utils import excutils
+import six
 import webob.exc
 
 import glance.api.policy
@@ -94,7 +96,7 @@ class ImageDataController(object):
                 if CONF.data_api == 'glance.db.registry.api':
                     # create a trust if backend is registry
                     try:
-                        # request user pluging for current token
+                        # request user plugin for current token
                         user_plugin = req.environ.get('keystone.token_auth')
                         roles = []
                         # use roles from request environment because they
@@ -110,19 +112,19 @@ class ImageDataController(object):
                                      "Use the existing user token."),
                                  encodeutils.exception_to_unicode(e))
 
-                image_repo.save(image)
+                image_repo.save(image, from_state='queued')
                 image.set_data(data, size)
 
                 try:
                     image_repo.save(image, from_state='saving')
-                except exception.NotAuthenticated as e:
+                except exception.NotAuthenticated:
                     if refresher is not None:
                         # request a new token to update an image in database
                         cxt.auth_token = refresher.refresh_token()
                         image_repo = self.gateway.get_repo(req.context)
                         image_repo.save(image, from_state='saving')
                     else:
-                        raise e
+                        raise
 
                 try:
                     # release resources required for re-auth
@@ -225,7 +227,7 @@ class ImageDataController(object):
             raise webob.exc.HTTPServiceUnavailable(explanation=msg,
                                                    request=req)
 
-        except exception.SignatureVerificationError as e:
+        except cursive_exception.SignatureVerificationError as e:
             msg = (_LE("Signature verification failed for image %(id)s: %(e)s")
                    % {'id': image_id,
                       'e': encodeutils.exception_to_unicode(e)})
@@ -281,17 +283,20 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
 
     def download(self, response, image):
         offset, chunk_size = 0, None
-        range_val = response.request.get_content_range()
+        # NOTE(dharinic): In case of a malformed content range,
+        # glance/common/wsgi.py will raise HTTPRequestRangeNotSatisfiable
+        # (setting status_code to 416)
+        range_val = response.request.get_content_range(image.size)
 
         if range_val:
             # NOTE(flaper87): if not present, both, start
             # and stop, will be None.
-            if range_val.start is not None:
+            if range_val.start is not None and range_val.stop is not None:
                 offset = range_val.start
-
-            if range_val.stop is not None:
                 chunk_size = range_val.stop - offset
 
+            response.status_int = 206
+
         response.headers['Content-Type'] = 'application/octet-stream'
 
         try:
@@ -300,6 +305,11 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
             # an iterator very strange
             response.app_iter = iter(image.get_data(offset=offset,
                                                     chunk_size=chunk_size))
+            # NOTE(dharinic): In case of a full image download, when
+            # chunk_size was none, reset it to image.size to set the
+            # response header's Content-Length.
+            if not chunk_size:
+                chunk_size = image.size
         except glance_store.NotFound as e:
             raise webob.exc.HTTPNoContent(explanation=e.msg)
         except glance_store.RemoteServiceUnavailable as e:
@@ -317,7 +327,7 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
             response.headers['Content-MD5'] = image.checksum
         # NOTE(markwash): "response.app_iter = ..." also erroneously resets the
         # content-length
-        response.headers['Content-Length'] = str(image.size)
+        response.headers['Content-Length'] = six.text_type(chunk_size)
 
     def upload(self, response, result):
         response.status_int = 204
