@@ -17,6 +17,7 @@ from oslo_log import log as logging
 from oslo_serialization import jsonutils
 from oslo_utils import encodeutils
 import six
+from six.moves import http_client as http
 import webob.exc
 from wsme.rest import json
 
@@ -327,7 +328,7 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
         self.schema = schema or get_schema()
 
     def create(self, response, metadata_object):
-        response.status_int = 201
+        response.status_int = http.CREATED
         self.show(response, metadata_object)
 
     def show(self, response, metadata_object):
@@ -337,7 +338,7 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
         response.content_type = 'application/json'
 
     def update(self, response, metadata_object):
-        response.status_int = 200
+        response.status_int = http.OK
         self.show(response, metadata_object)
 
     def index(self, response, result):
@@ -348,7 +349,7 @@ class ResponseSerializer(wsgi.JSONResponseSerializer):
         response.content_type = 'application/json'
 
     def delete(self, response, result):
-        response.status_int = 204
+        response.status_int = http.NO_CONTENT
 
 
 def get_object_href(namespace_name, metadef_object):
