@@ -39,8 +39,9 @@ possible_topdir = os.path.normpath(os.path.join(os.path.abspath(sys.argv[0]),
 if os.path.exists(os.path.join(possible_topdir, 'glance', '__init__.py')):
     sys.path.insert(0, possible_topdir)
 
+from alembic import command as alembic_command
+
 from oslo_config import cfg
-from oslo_db.sqlalchemy import migration
 from oslo_log import log as logging
 from oslo_utils import encodeutils
 import six
@@ -49,6 +50,8 @@ from glance.common import config
 from glance.common import exception
 from glance import context
 from glance.db import migration as db_migration
+from glance.db.sqlalchemy import alembic_migrations
+from glance.db.sqlalchemy.alembic_migrations import data_migrations
 from glance.db.sqlalchemy import api as db_api
 from glance.db.sqlalchemy import metadata
 from glance.i18n import _
@@ -73,39 +76,133 @@ class DbCommands(object):
 
     def version(self):
         """Print database's current migration level"""
-        print(migration.db_version(db_api.get_engine(),
-                                   db_migration.MIGRATE_REPO_PATH,
-                                   db_migration.INIT_VERSION))
+        current_heads = alembic_migrations.get_current_alembic_heads()
+        if current_heads:
+            # Migrations are managed by alembic
+            for head in current_heads:
+                print(head)
+        else:
+            # Migrations are managed by legacy versioning scheme
+            print(_('Database is either not under migration control or under '
+                    'legacy migration control, please run '
+                    '"glance-manage db sync" to place the database under '
+                    'alembic migration control.'))
 
     @args('--version', metavar='<version>', help='Database version')
-    def upgrade(self, version=None):
+    def upgrade(self, version=db_migration.LATEST_REVISION):
         """Upgrade the database's migration level"""
-        migration.db_sync(db_api.get_engine(),
-                          db_migration.MIGRATE_REPO_PATH,
-                          version)
+        self.sync(version)
 
     @args('--version', metavar='<version>', help='Database version')
-    def version_control(self, version=None):
+    def version_control(self, version=db_migration.ALEMBIC_INIT_VERSION):
         """Place a database under migration control"""
-        migration.db_version_control(db_api.get_engine(),
-                                     db_migration.MIGRATE_REPO_PATH,
-                                     version)
+
+        if version is None:
+            version = db_migration.ALEMBIC_INIT_VERSION
+
+        a_config = alembic_migrations.get_alembic_config()
+        alembic_command.stamp(a_config, version)
+        print(_("Placed database under migration control at "
+                "revision:"), version)
 
     @args('--version', metavar='<version>', help='Database version')
-    @args('--current_version', metavar='<version>',
-          help='Current Database version')
-    def sync(self, version=None, current_version=None):
+    def sync(self, version=db_migration.LATEST_REVISION):
         """
-        Place a database under migration control and upgrade it,
-        creating first if necessary.
+        Place an existing database under migration control and upgrade it.
         """
-        if current_version not in (None, 'None'):
-            migration.db_version_control(db_api.get_engine(),
-                                         db_migration.MIGRATE_REPO_PATH,
-                                         version=current_version)
-        migration.db_sync(db_api.get_engine(),
-                          db_migration.MIGRATE_REPO_PATH,
-                          version)
+        if version is None:
+            version = db_migration.LATEST_REVISION
+
+        alembic_migrations.place_database_under_alembic_control()
+
+        a_config = alembic_migrations.get_alembic_config()
+        alembic_command.upgrade(a_config, version)
+        heads = alembic_migrations.get_current_alembic_heads()
+        if heads is None:
+            raise exception.GlanceException("Database sync failed")
+        revs = ", ".join(heads)
+        if version == 'heads':
+            print(_("Upgraded database, current revision(s):"), revs)
+        else:
+            print(_('Upgraded database to: %(v)s, current revision(s): %(r)s')
+                  % {'v': version, 'r': revs})
+
+    def expand(self):
+        """Run the expansion phase of a rolling upgrade procedure."""
+        engine = db_api.get_engine()
+        if engine.engine.name != 'mysql':
+            sys.exit(_('Rolling upgrades are currently supported only for '
+                       'MySQL'))
+
+        expand_head = alembic_migrations.get_alembic_branch_head(
+            db_migration.EXPAND_BRANCH)
+        if not expand_head:
+            sys.exit(_('Database expansion failed. Couldn\'t find head '
+                       'revision of expand branch.'))
+
+        self.sync(version=expand_head)
+
+        curr_heads = alembic_migrations.get_current_alembic_heads()
+        if expand_head not in curr_heads:
+            sys.exit(_('Database expansion failed. Database expansion should '
+                       'have brought the database version up to "%(e_rev)s" '
+                       'revision. But, current revisions are: %(curr_revs)s ')
+                     % {'e_rev': expand_head, 'curr_revs': curr_heads})
+
+    def contract(self):
+        """Run the contraction phase of a rolling upgrade procedure."""
+        engine = db_api.get_engine()
+        if engine.engine.name != 'mysql':
+            sys.exit(_('Rolling upgrades are currently supported only for '
+                       'MySQL'))
+
+        contract_head = alembic_migrations.get_alembic_branch_head(
+            db_migration.CONTRACT_BRANCH)
+        if not contract_head:
+            sys.exit(_('Database contraction failed. Couldn\'t find head '
+                       'revision of contract branch.'))
+
+        curr_heads = alembic_migrations.get_current_alembic_heads()
+        expand_head = alembic_migrations.get_alembic_branch_head(
+            db_migration.EXPAND_BRANCH)
+        if expand_head not in curr_heads:
+            sys.exit(_('Database contraction did not run. Database '
+                       'contraction cannot be run before database expansion. '
+                       'Run database expansion first using '
+                       '"glance-manage db expand"'))
+
+        if data_migrations.has_pending_migrations(db_api.get_engine()):
+            sys.exit(_('Database contraction did not run. Database '
+                       'contraction cannot be run before data migration is '
+                       'complete. Run data migration using "glance-manage db '
+                       'migrate".'))
+
+        self.sync(version=contract_head)
+
+        curr_heads = alembic_migrations.get_current_alembic_heads()
+        if contract_head not in curr_heads:
+            sys.exit(_('Database contraction failed. Database contraction '
+                       'should have brought the database version up to '
+                       '"%(e_rev)s" revision. But, current revisions are: '
+                       '%(curr_revs)s ') % {'e_rev': expand_head,
+                                            'curr_revs': curr_heads})
+
+    def migrate(self):
+        engine = db_api.get_engine()
+        if engine.engine.name != 'mysql':
+            sys.exit(_('Rolling upgrades are currently supported only for '
+                       'MySQL'))
+
+        curr_heads = alembic_migrations.get_current_alembic_heads()
+        expand_head = alembic_migrations.get_alembic_branch_head(
+            db_migration.EXPAND_BRANCH)
+        if expand_head not in curr_heads:
+            sys.exit(_('Data migration did not run. Data migration cannot be '
+                       'run before database expansion. Run database '
+                       'expansion first using "glance-manage db expand"'))
+
+        rows_migrated = data_migrations.migrate(db_api.get_engine())
+        print(_('Migrated %s rows') % rows_migrated)
 
     @args('--path', metavar='<path>', help='Path to the directory or file '
                                            'where json metadata is stored')
@@ -157,8 +254,8 @@ class DbCommands(object):
             sys.exit(_("Invalid int value for max_rows: "
                        "%(max_rows)s") % {'max_rows': max_rows})
 
-        if age_in_days <= 0:
-            sys.exit(_("Must supply a positive, non-zero value for age."))
+        if age_in_days < 0:
+            sys.exit(_("Must supply a non-negative value for age."))
         if age_in_days >= (int(time.time()) / 86400):
             sys.exit(_("Maximal age is count of days since epoch."))
         if max_rows < 1:
@@ -179,15 +276,23 @@ class DbLegacyCommands(object):
     def version(self):
         self.command_object.version()
 
-    def upgrade(self, version=None):
+    def upgrade(self, version=db_migration.LATEST_REVISION):
         self.command_object.upgrade(CONF.command.version)
 
-    def version_control(self, version=None):
+    def version_control(self, version=db_migration.ALEMBIC_INIT_VERSION):
         self.command_object.version_control(CONF.command.version)
 
-    def sync(self, version=None, current_version=None):
-        self.command_object.sync(CONF.command.version,
-                                 CONF.command.current_version)
+    def sync(self, version=db_migration.LATEST_REVISION):
+        self.command_object.sync(CONF.command.version)
+
+    def expand(self):
+        self.command_object.expand()
+
+    def contract(self):
+        self.command_object.contract()
+
+    def migrate(self):
+        self.command_object.migrate()
 
     def load_metadefs(self, path=None, merge=False,
                       prefer_new=False, overwrite=False):
@@ -224,9 +329,20 @@ def add_legacy_command_parsers(command_object, subparsers):
     parser = subparsers.add_parser('db_sync')
     parser.set_defaults(action_fn=legacy_command_object.sync)
     parser.add_argument('version', nargs='?')
-    parser.add_argument('current_version', nargs='?')
     parser.set_defaults(action='db_sync')
 
+    parser = subparsers.add_parser('db_expand')
+    parser.set_defaults(action_fn=legacy_command_object.expand)
+    parser.set_defaults(action='db_expand')
+
+    parser = subparsers.add_parser('db_contract')
+    parser.set_defaults(action_fn=legacy_command_object.contract)
+    parser.set_defaults(action='db_contract')
+
+    parser = subparsers.add_parser('db_migrate')
+    parser.set_defaults(action_fn=legacy_command_object.migrate)
+    parser.set_defaults(action='db_migrate')
+
     parser = subparsers.add_parser('db_load_metadefs')
     parser.set_defaults(action_fn=legacy_command_object.load_metadefs)
     parser.add_argument('path', nargs='?')
@@ -313,6 +429,7 @@ def main():
 
     try:
         logging.register_options(CONF)
+        CONF.set_default(name='use_stderr', default=True, enforce_type=True)
         cfg_files = cfg.find_config_files(project='glance',
                                           prog='glance-registry')
         cfg_files.extend(cfg.find_config_files(project='glance',
