@@ -19,9 +19,7 @@
 import six
 import six.moves.urllib.parse as urlparse
 
-from glance import i18n
-
-_ = i18n._
+from glance.i18n import _
 
 _FATAL_EXCEPTION_FORMAT_ERRORS = False
 
@@ -115,7 +113,7 @@ class UploadException(GlanceException):
 
 
 class Forbidden(GlanceException):
-    message = _("You are not authorized to complete this action.")
+    message = _("You are not authorized to complete %(action)s action.")
 
 
 class ForbiddenPublicImage(Forbidden):
@@ -176,6 +174,10 @@ class InvalidSwiftStoreConfiguration(Invalid):
     message = _("Invalid configuration in glance-swift conf file.")
 
 
+class InvalidFilterOperatorValue(Invalid):
+    message = _("Unable to filter using the specified operator.")
+
+
 class InvalidFilterRangeValue(Invalid):
     message = _("Unable to filter using the specified range.")
 
@@ -286,10 +288,6 @@ class InvalidObject(GlanceException):
                 "'%(schema)s': %(reason)s")
 
 
-class UnsupportedHeaderFeature(GlanceException):
-    message = _("Provided header feature is unsupported: %(feature)s")
-
-
 class ImageSizeLimitExceeded(GlanceException):
     message = _("The provided image is too large.")
 
@@ -352,14 +350,14 @@ class InvalidTaskStatusTransition(TaskException, Invalid):
                 " %(new_status)s is not allowed")
 
 
+class ImportTaskError(TaskException, Invalid):
+    message = _("An import task exception occurred")
+
+
 class DuplicateLocation(Duplicate):
     message = _("The location %(location)s already exists")
 
 
-class ImageDataNotFound(NotFound):
-    message = _("No image data could be found")
-
-
 class InvalidParameterValue(Invalid):
     message = _("Invalid value '%(value)s' for parameter '%(param)s': "
                 "%(extra_msg)s")
@@ -399,7 +397,9 @@ class MetadefDuplicateResourceTypeAssociation(Duplicate):
 
 class MetadefDuplicateTag(Duplicate):
     message = _("A metadata tag with name=%(name)s"
-                " already exists in namespace=%(namespace_name)s.")
+                " already exists in namespace=%(namespace_name)s."
+                " (Please note that metadata tag names are"
+                " case insensitive).")
 
 
 class MetadefForbidden(Forbidden):
@@ -414,7 +414,7 @@ class MetadefIntegrityError(Forbidden):
 
 class MetadefNamespaceNotFound(NotFound):
     message = _("Metadata definition namespace=%(namespace_name)s"
-                "was not found.")
+                " was not found.")
 
 
 class MetadefObjectNotFound(NotFound):
@@ -447,10 +447,6 @@ class MetadefTagNotFound(NotFound):
                 " namespace=%(namespace_name)s.")
 
 
-class SignatureVerificationError(GlanceException):
-    message = _("Unable to verify signature: %(reason)s")
-
-
 class InvalidVersion(Invalid):
     message = _("Version is invalid: %(reason)s")
 
@@ -529,8 +525,8 @@ class ArtifactLoadError(GlanceException):
 
 
 class ArtifactNonMatchingTypeName(ArtifactLoadError):
-    message = _(
-        "Plugin name '%(plugin)s' should match artifact typename '%(name)s'")
+    message = _("Plugin name '%(plugin)s' should match "
+                "artifact typename '%(name)s'")
 
 
 class ArtifactPluginNotFound(NotFound):
@@ -561,3 +557,9 @@ class InvalidJsonPatchPath(JsonPatchException):
     def __init__(self, message=None, *args, **kwargs):
         self.explanation = kwargs.get("explanation")
         super(InvalidJsonPatchPath, self).__init__(message, *args, **kwargs)
+
+
+class InvalidDataMigrationScript(GlanceException):
+    message = _("Invalid data migration script '%(script)s'. A valid data "
+                "migration script must implement functions 'has_migrations' "
+                "and 'migrate'.")
