@@ -22,6 +22,7 @@ import sys
 
 from oslo_serialization import jsonutils
 from oslo_utils import units
+from six.moves import http_client
 # NOTE(jokke): simplified transition to py3, behaves like py2 xrange
 from six.moves import range
 
@@ -37,7 +38,7 @@ class TestApi(functional.FunctionalTest):
 
     """Functional tests using httplib2 against the API server"""
 
-    def _check_image_create(self, headers, status=201,
+    def _check_image_create(self, headers, status=http_client.CREATED,
                             image_data="*" * FIVE_KB):
         # performs image_create request, checks the response and returns
         # content
@@ -56,7 +57,7 @@ class TestApi(functional.FunctionalTest):
 
         # checksum can be no longer that 32 characters (String(32))
         headers['X-Image-Meta-Checksum'] = 'x' * 42
-        content = self._check_image_create(headers, 400)
+        content = self._check_image_create(headers, http_client.BAD_REQUEST)
         self.assertIn("Invalid checksum", content)
         # test positive case as well
         headers['X-Image-Meta-Checksum'] = hashlib.md5(image_data).hexdigest()
@@ -71,16 +72,120 @@ class TestApi(functional.FunctionalTest):
             headers = minimal_headers('Image1')
             # check that long numbers result in 400
             headers['X-Image-Meta-%s' % param] = str(sys.maxint + 1)
-            content = self._check_image_create(headers, 400)
+            content = self._check_image_create(headers,
+                                               http_client.BAD_REQUEST)
             self.assertIn("'%s' value out of range" % param, content)
             # check that integers over 4 byte result in 400
             headers['X-Image-Meta-%s' % param] = str(2 ** 31)
-            content = self._check_image_create(headers, 400)
+            content = self._check_image_create(headers,
+                                               http_client.BAD_REQUEST)
             self.assertIn("'%s' value out of range" % param, content)
             # verify positive case as well
             headers['X-Image-Meta-%s' % param] = str((2 ** 31) - 1)
             self._check_image_create(headers)
 
+    def test_updating_is_public(self):
+        """Verify that we can update the is_public attribute."""
+        self.cleanup()
+        self.start_servers(**self.__dict__.copy())
+
+        # Verify no public images
+        path = "http://%s:%d/v1/images" % ("127.0.0.1", self.api_port)
+        http = httplib2.Http()
+        response, content = http.request(path, 'GET')
+        self.assertEqual(http_client.OK, response.status)
+        self.assertEqual('{"images": []}', content)
+
+        # Verify no public images
+        path = "http://%s:%d/v1/images/detail" % ("127.0.0.1", self.api_port)
+        http = httplib2.Http()
+        response, content = http.request(path, 'GET')
+        self.assertEqual(http_client.OK, response.status)
+        self.assertEqual('{"images": []}', content)
+
+        # POST /images with private image named Image1
+        # attribute and no custom properties. Verify a 200 OK is returned
+        image_data = "*" * FIVE_KB
+        headers = minimal_headers('Image1', public=False)
+        path = "http://%s:%d/v1/images" % ("127.0.0.1", self.api_port)
+        http = httplib2.Http()
+        response, content = http.request(path, 'POST', headers=headers,
+                                         body=image_data)
+        self.assertEqual(http_client.CREATED, response.status)
+        data = jsonutils.loads(content)
+        image_id = data['image']['id']
+        self.assertEqual(hashlib.md5(image_data).hexdigest(),
+                         data['image']['checksum'])
+        self.assertEqual(FIVE_KB, data['image']['size'])
+        self.assertEqual("Image1", data['image']['name'])
+        self.assertFalse(data['image']['is_public'])
+
+        # Retrieve image again to verify it was created appropriately
+        path = "http://%s:%d/v1/images/%s" % ("127.0.0.1", self.api_port,
+                                              image_id)
+        http = httplib2.Http()
+        response, content = http.request(path, 'GET')
+        self.assertEqual(http_client.OK, response.status)
+
+        expected_image_headers = {
+            'x-image-meta-id': image_id,
+            'x-image-meta-name': 'Image1',
+            'x-image-meta-is_public': 'False',
+            'x-image-meta-status': 'active',
+            'x-image-meta-disk_format': 'raw',
+            'x-image-meta-container_format': 'ovf',
+            'x-image-meta-size': str(FIVE_KB)}
+
+        expected_std_headers = {
+            'content-length': str(FIVE_KB),
+            'content-type': 'application/octet-stream'}
+
+        for expected_key, expected_value in expected_image_headers.items():
+            self.assertEqual(expected_value, response[expected_key],
+                             "For key '%s' expected header value '%s'. "
+                             "Got '%s'" % (expected_key,
+                                           expected_value,
+                                           response[expected_key]))
+
+        for expected_key, expected_value in expected_std_headers.items():
+            self.assertEqual(expected_value, response[expected_key],
+                             "For key '%s' expected header value '%s'. "
+                             "Got '%s'" % (expected_key,
+                                           expected_value,
+                                           response[expected_key]))
+
+        self.assertEqual("*" * FIVE_KB, content)
+        self.assertEqual(hashlib.md5("*" * FIVE_KB).hexdigest(),
+                         hashlib.md5(content).hexdigest())
+
+        # PUT image with custom properties to make public and then
+        # Verify 200 returned
+        headers = {'X-Image-Meta-is_public': 'True'}
+        path = "http://%s:%d/v1/images/%s" % ("127.0.0.1", self.api_port,
+                                              image_id)
+        http = httplib2.Http()
+        response, content = http.request(path, 'PUT', headers=headers)
+        self.assertEqual(http_client.OK, response.status)
+        image = jsonutils.loads(content)
+        is_public = image['image']['is_public']
+        self.assertTrue(
+            is_public,
+            "Expected image to be public but received %s" % is_public)
+
+        # PUT image with custom properties to make private and then
+        # Verify 200 returned
+        headers = {'X-Image-Meta-is_public': 'False'}
+        path = "http://%s:%d/v1/images/%s" % ("127.0.0.1", self.api_port,
+                                              image_id)
+        http = httplib2.Http()
+        response, content = http.request(path, 'PUT', headers=headers)
+        self.assertEqual(http_client.OK, response.status)
+        image = jsonutils.loads(content)
+        is_public = image['image']['is_public']
+        self.assertFalse(
+            is_public,
+            "Expected image to be private but received %s" % is_public)
+
     @skip_if_disabled
     def test_get_head_simple_post(self):
         """
@@ -165,7 +270,7 @@ class TestApi(functional.FunctionalTest):
         path = "http://%s:%d/v1/images" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         self.assertEqual('{"images": []}', content)
 
         # 1. GET /images/detail
@@ -173,7 +278,7 @@ class TestApi(functional.FunctionalTest):
         path = "http://%s:%d/v1/images/detail" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         self.assertEqual('{"images": []}', content)
 
         # 2. POST /images with public image named Image1
@@ -184,7 +289,7 @@ class TestApi(functional.FunctionalTest):
         http = httplib2.Http()
         response, content = http.request(path, 'POST', headers=headers,
                                          body=image_data)
-        self.assertEqual(201, response.status)
+        self.assertEqual(http_client.CREATED, response.status)
         data = jsonutils.loads(content)
         image_id = data['image']['id']
         self.assertEqual(hashlib.md5(image_data).hexdigest(),
@@ -199,7 +304,7 @@ class TestApi(functional.FunctionalTest):
                                               image_id)
         http = httplib2.Http()
         response, content = http.request(path, 'HEAD')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         self.assertEqual("Image1", response['x-image-meta-name'])
 
         # 4. GET image
@@ -208,7 +313,7 @@ class TestApi(functional.FunctionalTest):
                                               image_id)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
 
         expected_image_headers = {
             'x-image-meta-id': image_id,
@@ -246,7 +351,7 @@ class TestApi(functional.FunctionalTest):
         path = "http://%s:%d/v1/images" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
 
         expected_result = {"images": [
             {"container_format": "ovf",
@@ -262,7 +367,7 @@ class TestApi(functional.FunctionalTest):
         path = "http://%s:%d/v1/images/detail" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
 
         expected_image = {
             "status": "active",
@@ -293,7 +398,7 @@ class TestApi(functional.FunctionalTest):
                                               image_id)
         http = httplib2.Http()
         response, content = http.request(path, 'PUT', headers=headers)
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         data = jsonutils.loads(content)
         self.assertEqual("x86_64", data['image']['properties']['arch'])
         self.assertEqual("Ubuntu", data['image']['properties']['distro'])
@@ -307,14 +412,15 @@ class TestApi(functional.FunctionalTest):
                                               image_id)
         http = httplib2.Http()
         response, content = http.request(path, 'PUT', headers=headers)
-        self.assertEqual(413, response.status)
+        self.assertEqual(http_client.REQUEST_ENTITY_TOO_LARGE,
+                         response.status)
 
         # 9. GET /images/detail
         # Verify image and all its metadata
         path = "http://%s:%d/v1/images/detail" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
 
         expected_image = {
             "status": "active",
@@ -343,11 +449,11 @@ class TestApi(functional.FunctionalTest):
                                               image_id)
         http = httplib2.Http()
         response, content = http.request(path, 'PUT', headers=headers)
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
 
         path = "http://%s:%d/v1/images/detail" % ("127.0.0.1", self.api_port)
         response, content = http.request(path, 'GET')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         data = jsonutils.loads(content)['images'][0]
         self.assertEqual(1, len(data['properties']))
         self.assertEqual("x86_64", data['properties']['arch'])
@@ -359,12 +465,12 @@ class TestApi(functional.FunctionalTest):
                                               image_id)
         http = httplib2.Http()
         response, content = http.request(path, 'PUT', headers=headers)
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         data = jsonutils.loads(content)
 
         path = "http://%s:%d/v1/images/detail" % ("127.0.0.1", self.api_port)
         response, content = http.request(path, 'GET')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         data = jsonutils.loads(content)['images'][0]
         self.assertEqual(2, len(data['properties']))
         self.assertEqual("x86_64", data['properties']['arch'])
@@ -376,21 +482,21 @@ class TestApi(functional.FunctionalTest):
                 ("127.0.0.1", self.api_port, image_id))
         http = httplib2.Http()
         response, content = http.request(path, 'PUT')
-        self.assertEqual(204, response.status)
+        self.assertEqual(http_client.NO_CONTENT, response.status)
 
         # 13. Add member to image
         path = ("http://%s:%d/v1/images/%s/members/pattiewhite" %
                 ("127.0.0.1", self.api_port, image_id))
         http = httplib2.Http()
         response, content = http.request(path, 'PUT')
-        self.assertEqual(204, response.status)
+        self.assertEqual(http_client.NO_CONTENT, response.status)
 
         # 14. List image members
         path = ("http://%s:%d/v1/images/%s/members" %
                 ("127.0.0.1", self.api_port, image_id))
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         data = jsonutils.loads(content)
         self.assertEqual(2, len(data['members']))
         self.assertEqual('pattieblack', data['members'][0]['member_id'])
@@ -401,7 +507,7 @@ class TestApi(functional.FunctionalTest):
                 ("127.0.0.1", self.api_port, image_id))
         http = httplib2.Http()
         response, content = http.request(path, 'DELETE')
-        self.assertEqual(204, response.status)
+        self.assertEqual(http_client.NO_CONTENT, response.status)
 
         # 16. Attempt to replace members with an overlimit amount
         # Adding 11 image members should fail since configured limit is 10
@@ -414,7 +520,8 @@ class TestApi(functional.FunctionalTest):
         http = httplib2.Http()
         body = jsonutils.dumps(dict(memberships=memberships))
         response, content = http.request(path, 'PUT', body=body)
-        self.assertEqual(413, response.status)
+        self.assertEqual(http_client.REQUEST_ENTITY_TOO_LARGE,
+                         response.status)
 
         # 17. Attempt to add a member while at limit
         # Adding an 11th member should fail since configured limit is 10
@@ -427,13 +534,14 @@ class TestApi(functional.FunctionalTest):
         http = httplib2.Http()
         body = jsonutils.dumps(dict(memberships=memberships))
         response, content = http.request(path, 'PUT', body=body)
-        self.assertEqual(204, response.status)
+        self.assertEqual(http_client.NO_CONTENT, response.status)
 
         path = ("http://%s:%d/v1/images/%s/members/fail_me" %
                 ("127.0.0.1", self.api_port, image_id))
         http = httplib2.Http()
         response, content = http.request(path, 'PUT')
-        self.assertEqual(413, response.status)
+        self.assertEqual(http_client.REQUEST_ENTITY_TOO_LARGE,
+                         response.status)
 
         # 18. POST /images with another public image named Image2
         # attribute and three custom properties, "distro", "arch" & "foo".
@@ -447,7 +555,7 @@ class TestApi(functional.FunctionalTest):
         http = httplib2.Http()
         response, content = http.request(path, 'POST', headers=headers,
                                          body=image_data)
-        self.assertEqual(201, response.status)
+        self.assertEqual(http_client.CREATED, response.status)
         data = jsonutils.loads(content)
         image2_id = data['image']['id']
         self.assertEqual(hashlib.md5(image_data).hexdigest(),
@@ -465,7 +573,7 @@ class TestApi(functional.FunctionalTest):
                                               image2_id)
         http = httplib2.Http()
         response, content = http.request(path, 'HEAD')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         self.assertEqual("Image2", response['x-image-meta-name'])
 
         # 20. GET /images
@@ -473,7 +581,7 @@ class TestApi(functional.FunctionalTest):
         path = "http://%s:%d/v1/images" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         images = jsonutils.loads(content)['images']
         self.assertEqual(2, len(images))
         self.assertEqual(image2_id, images[0]['id'])
@@ -485,7 +593,7 @@ class TestApi(functional.FunctionalTest):
             "127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         images = jsonutils.loads(content)['images']
         self.assertEqual(2, len(images))
         self.assertEqual(image2_id, images[0]['id'])
@@ -497,7 +605,7 @@ class TestApi(functional.FunctionalTest):
             "127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         images = jsonutils.loads(content)['images']
         self.assertEqual(0, len(images))
 
@@ -507,7 +615,7 @@ class TestApi(functional.FunctionalTest):
                                                             self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         images = jsonutils.loads(content)['images']
         self.assertEqual(0, len(images))
 
@@ -517,7 +625,7 @@ class TestApi(functional.FunctionalTest):
                                                               self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         images = jsonutils.loads(content)['images']
         self.assertEqual(1, len(images))
         self.assertEqual(image2_id, images[0]['id'])
@@ -528,7 +636,7 @@ class TestApi(functional.FunctionalTest):
                                                                 self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         images = jsonutils.loads(content)['images']
         self.assertEqual(1, len(images))
         self.assertEqual(image_id, images[0]['id'])
@@ -539,7 +647,7 @@ class TestApi(functional.FunctionalTest):
                                                             self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         images = jsonutils.loads(content)['images']
         self.assertEqual(1, len(images))
         self.assertEqual(image2_id, images[0]['id'])
@@ -549,14 +657,14 @@ class TestApi(functional.FunctionalTest):
                                               image_id)
         http = httplib2.Http()
         response, content = http.request(path, 'DELETE')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
 
         # 28. Try to list members of deleted image
         path = ("http://%s:%d/v1/images/%s/members" %
                 ("127.0.0.1", self.api_port, image_id))
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(404, response.status)
+        self.assertEqual(http_client.NOT_FOUND, response.status)
 
         # 29. Try to update member of deleted image
         path = ("http://%s:%d/v1/images/%s/members" %
@@ -565,35 +673,35 @@ class TestApi(functional.FunctionalTest):
         fixture = [{'member_id': 'pattieblack', 'can_share': 'false'}]
         body = jsonutils.dumps(dict(memberships=fixture))
         response, content = http.request(path, 'PUT', body=body)
-        self.assertEqual(404, response.status)
+        self.assertEqual(http_client.NOT_FOUND, response.status)
 
         # 30. Try to add member to deleted image
         path = ("http://%s:%d/v1/images/%s/members/chickenpattie" %
                 ("127.0.0.1", self.api_port, image_id))
         http = httplib2.Http()
         response, content = http.request(path, 'PUT')
-        self.assertEqual(404, response.status)
+        self.assertEqual(http_client.NOT_FOUND, response.status)
 
         # 31. Try to delete member of deleted image
         path = ("http://%s:%d/v1/images/%s/members/pattieblack" %
                 ("127.0.0.1", self.api_port, image_id))
         http = httplib2.Http()
         response, content = http.request(path, 'DELETE')
-        self.assertEqual(404, response.status)
+        self.assertEqual(http_client.NOT_FOUND, response.status)
 
         # 32. DELETE image2
         path = "http://%s:%d/v1/images/%s" % ("127.0.0.1", self.api_port,
                                               image2_id)
         http = httplib2.Http()
         response, content = http.request(path, 'DELETE')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
 
         # 33. GET /images
         # Verify no images are listed
         path = "http://%s:%d/v1/images" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         images = jsonutils.loads(content)['images']
         self.assertEqual(0, len(images))
 
@@ -601,27 +709,28 @@ class TestApi(functional.FunctionalTest):
         path = "http://%s:%d/v1/images/detail" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'HEAD')
-        self.assertEqual(405, response.status)
+        self.assertEqual(http_client.METHOD_NOT_ALLOWED, response.status)
         self.assertEqual('GET', response.get('allow'))
 
         self.stop_servers()
 
     def test_download_non_exists_image_raises_http_forbidden(self):
         """
-        We test the following sequential series of actions:
+        We test the following sequential series of actions::
+
+            0. POST /images with public image named Image1
+               and no custom properties
+               - Verify 201 returned
+            1. HEAD image
+               - Verify HTTP headers have correct information we just added
+            2. GET image
+               - Verify all information on image we just added is correct
+            3. DELETE image1
+               - Delete the newly added image
+            4. GET image
+               - Verify that 403 HTTPForbidden exception is raised prior to
+                 404 HTTPNotFound
 
-        0. POST /images with public image named Image1
-        and no custom properties
-        - Verify 201 returned
-        1. HEAD image
-        - Verify HTTP headers have correct information we just added
-        2. GET image
-        - Verify all information on image we just added is correct
-        3. DELETE image1
-        - Delete the newly added image
-        4. GET image
-        - Verify that 403 HTTPForbidden exception is raised prior to
-          404 HTTPNotFound
         """
         self.cleanup()
         self.start_servers(**self.__dict__.copy())
@@ -632,7 +741,7 @@ class TestApi(functional.FunctionalTest):
         http = httplib2.Http()
         response, content = http.request(path, 'POST', headers=headers,
                                          body=image_data)
-        self.assertEqual(201, response.status)
+        self.assertEqual(http_client.CREATED, response.status)
         data = jsonutils.loads(content)
         image_id = data['image']['id']
         self.assertEqual(hashlib.md5(image_data).hexdigest(),
@@ -647,7 +756,7 @@ class TestApi(functional.FunctionalTest):
                                               image_id)
         http = httplib2.Http()
         response, content = http.request(path, 'HEAD')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         self.assertEqual("Image1", response['x-image-meta-name'])
 
         # 2. GET /images
@@ -655,7 +764,7 @@ class TestApi(functional.FunctionalTest):
         path = "http://%s:%d/v1/images" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
 
         expected_result = {"images": [
             {"container_format": "ovf",
@@ -671,7 +780,7 @@ class TestApi(functional.FunctionalTest):
                                               image_id)
         http = httplib2.Http()
         response, content = http.request(path, 'DELETE')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
 
         # 4. GET image
         # Verify that 403 HTTPForbidden exception is raised prior to
@@ -682,7 +791,7 @@ class TestApi(functional.FunctionalTest):
                                               image_id)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(403, response.status)
+        self.assertEqual(http_client.FORBIDDEN, response.status)
 
         self.stop_servers()
 
@@ -711,7 +820,7 @@ class TestApi(functional.FunctionalTest):
         http = httplib2.Http()
         response, content = http.request(path, 'POST', headers=headers,
                                          body=image_data)
-        self.assertEqual(201, response.status)
+        self.assertEqual(http_client.CREATED, response.status)
         data = jsonutils.loads(content)
         image_id = data['image']['id']
         self.assertEqual(hashlib.md5(image_data).hexdigest(),
@@ -726,7 +835,7 @@ class TestApi(functional.FunctionalTest):
                                               image_id)
         http = httplib2.Http()
         response, content = http.request(path, 'HEAD')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         self.assertEqual("Image1", response['x-image-meta-name'])
 
         # 2. GET /images
@@ -734,7 +843,7 @@ class TestApi(functional.FunctionalTest):
         path = "http://%s:%d/v1/images" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
 
         expected_result = {"images": [
             {"container_format": "ovf",
@@ -750,7 +859,7 @@ class TestApi(functional.FunctionalTest):
                                               image_id)
         http = httplib2.Http()
         response, content = http.request(path, 'DELETE')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
 
         # 4. GET image
         # Verify that 404 HTTPNotFound exception is raised
@@ -758,7 +867,7 @@ class TestApi(functional.FunctionalTest):
                                               image_id)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
-        self.assertEqual(404, response.status)
+        self.assertEqual(http_client.NOT_FOUND, response.status)
 
         self.stop_servers()
 
@@ -775,7 +884,7 @@ class TestApi(functional.FunctionalTest):
         path = "http://%s:%d/v1/images" % ("127.0.0.1", self.api_port)
         response, content = http.request(path, 'POST', headers=headers,
                                          body=None)
-        self.assertEqual(201, response.status)
+        self.assertEqual(http_client.CREATED, response.status)
         image = jsonutils.loads(content)['image']
         self.assertEqual('queued', image['status'])
 
@@ -785,18 +894,18 @@ class TestApi(functional.FunctionalTest):
         http = httplib2.Http()
         headers = {'X-Image-Meta-Status': 'active'}
         response, content = http.request(path, 'PUT', headers=headers)
-        self.assertEqual(403, response.status)
+        self.assertEqual(http_client.FORBIDDEN, response.status)
         response, content = http.request(path, 'HEAD')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         self.assertEqual('queued', response['x-image-meta-status'])
 
         # We allow 'setting' to the same status
         http = httplib2.Http()
         headers = {'X-Image-Meta-Status': 'queued'}
         response, content = http.request(path, 'PUT', headers=headers)
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         response, content = http.request(path, 'HEAD')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         self.assertEqual('queued', response['x-image-meta-status'])
 
         # Make image active
@@ -804,7 +913,7 @@ class TestApi(functional.FunctionalTest):
         headers = {'Content-Type': 'application/octet-stream'}
         response, content = http.request(path, 'PUT', headers=headers,
                                          body='data')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         image = jsonutils.loads(content)['image']
         self.assertEqual('active', image['status'])
 
@@ -812,18 +921,18 @@ class TestApi(functional.FunctionalTest):
         http = httplib2.Http()
         headers = {'X-Image-Meta-Status': 'queued'}
         response, content = http.request(path, 'PUT', headers=headers)
-        self.assertEqual(403, response.status)
+        self.assertEqual(http_client.FORBIDDEN, response.status)
         response, content = http.request(path, 'HEAD')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         self.assertEqual('active', response['x-image-meta-status'])
 
         # We allow 'setting' to the same status
         http = httplib2.Http()
         headers = {'X-Image-Meta-Status': 'active'}
         response, content = http.request(path, 'PUT', headers=headers)
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         response, content = http.request(path, 'HEAD')
-        self.assertEqual(200, response.status)
+        self.assertEqual(http_client.OK, response.status)
         self.assertEqual('active', response['x-image-meta-status'])
 
         # Create a 'queued' image, ensure 'status' header is ignored
@@ -833,7 +942,7 @@ class TestApi(functional.FunctionalTest):
                    'X-Image-Meta-Status': 'active'}
         response, content = http.request(path, 'POST', headers=headers,
                                          body=None)
-        self.assertEqual(201, response.status)
+        self.assertEqual(http_client.CREATED, response.status)
         image = jsonutils.loads(content)['image']
         self.assertEqual('queued', image['status'])
 
@@ -846,7 +955,7 @@ class TestApi(functional.FunctionalTest):
                    'X-Image-Meta-Container-Format': 'bare'}
         response, content = http.request(path, 'POST', headers=headers,
                                          body='data')
-        self.assertEqual(201, response.status)
+        self.assertEqual(http_client.CREATED, response.status)
         image = jsonutils.loads(content)['image']
         self.assertEqual('active', image['status'])
         self.stop_servers()
