@@ -19,6 +19,7 @@ import os
 import uuid
 
 from mock import patch
+from six.moves import http_client as http
 from six.moves import reload_module
 import testtools
 
@@ -374,7 +375,7 @@ class TestRegistryV1Client(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
     def test_get_image_details(self):
         """Tests that the detailed info about public images returned"""
         fixture = self.get_fixture(id=UUID2, name='fake image #2',
-                                   properties={}, size=19)
+                                   properties={}, size=19, is_public=True)
 
         images = self.client.get_images_detailed()
 
@@ -645,7 +646,7 @@ class TestRegistryV1Client(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
 
     def test_add_image_basic(self):
         """Tests that we can add image metadata and returns the new id"""
-        fixture = self.get_fixture()
+        fixture = self.get_fixture(is_public=True)
 
         new_image = self.client.add_image(fixture)
 
@@ -662,7 +663,8 @@ class TestRegistryV1Client(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
     def test_add_image_with_properties(self):
         """Tests that we can add image metadata with properties"""
         fixture = self.get_fixture(location="file:///tmp/glance-tests/2",
-                                   properties={'distro': 'Ubuntu 10.04 LTS'})
+                                   properties={'distro': 'Ubuntu 10.04 LTS'},
+                                   is_public=True)
 
         new_image = self.client.add_image(fixture)
 
@@ -752,6 +754,34 @@ class TestRegistryV1Client(base.IsolatedUnitTest, test_utils.RegistryAPIMixIn):
         for k, v in fixture.items():
             self.assertEqual(v, data[k])
 
+    def test_update_image_public(self):
+        """Tests that the /images PUT registry API updates the image"""
+        fixture = {'name': 'fake public image #2',
+                   'is_public': True,
+                   'disk_format': 'vmdk'}
+
+        self.assertTrue(self.client.update_image(UUID2, fixture))
+
+        # Test all other attributes set
+        data = self.client.get_image(UUID2)
+
+        for k, v in fixture.items():
+            self.assertEqual(v, data[k])
+
+    def test_update_image_private(self):
+        """Tests that the /images PUT registry API updates the image"""
+        fixture = {'name': 'fake public image #2',
+                   'is_public': False,
+                   'disk_format': 'vmdk'}
+
+        self.assertTrue(self.client.update_image(UUID2, fixture))
+
+        # Test all other attributes set
+        data = self.client.get_image(UUID2)
+
+        for k, v in fixture.items():
+            self.assertEqual(v, data[k])
+
     def test_update_image_not_existing(self):
         """Tests non existing image update doesn't work"""
         fixture = self.get_fixture(status='bad status')
@@ -913,7 +943,7 @@ class TestRegistryV1ClientApi(base.IsolatedUnitTest):
 
 
 class FakeResponse(object):
-    status = 202
+    status = http.ACCEPTED
 
     def getheader(*args, **kwargs):
         return None
