@@ -18,6 +18,7 @@ import datetime
 import glance_store
 from oslo_config import cfg
 from oslo_serialization import jsonutils
+from six.moves import http_client as http
 import webob
 
 import glance.api.v2.image_members
@@ -49,7 +50,7 @@ def _db_fixture(id, **kwargs):
     obj = {
         'id': id,
         'name': None,
-        'is_public': False,
+        'visibility': 'shared',
         'properties': {},
         'checksum': None,
         'owner': None,
@@ -112,7 +113,7 @@ class TestImageMembersController(test_utils.BaseTestCase):
     def _create_images(self):
         self.images = [
             _db_fixture(UUID1, owner=TENANT1, name='1', size=256,
-                        is_public=True,
+                        visibility='public',
                         locations=[{'url': '%s/%s' % (BASE_URI, UUID1),
                                     'metadata': {}, 'status': 'active'}]),
             _db_fixture(UUID2, owner=TENANT1, name='2', size=512),
@@ -150,7 +151,7 @@ class TestImageMembersController(test_utils.BaseTestCase):
         self.assertEqual({'members': []}, output)
 
     def test_index_member_view(self):
-        # UUID3 is a private image owned by TENANT3
+        # UUID3 is a shared image owned by TENANT3
         # UUID3 has members TENANT2 and TENANT4
         # When TENANT4 lists members for UUID3, should not see TENANT2
         request = unit_test_utils.get_fake_request(tenant=TENANT4)
@@ -346,7 +347,7 @@ class TestImageMembersController(test_utils.BaseTestCase):
         image_id = UUID2
         res = self.controller.delete(request, image_id, member_id)
         self.assertEqual(b'', res.body)
-        self.assertEqual(204, res.status_code)
+        self.assertEqual(http.NO_CONTENT, res.status_code)
         found_member = self.db.image_member_find(
             request.context, image_id=image_id, member=member_id)
         self.assertEqual([], found_member)
